@@ -7,6 +7,7 @@ mod frame;
 mod imgutils;
 mod mem;
 mod motion_vector;
+mod pixdesc;
 mod pixfmt;
 mod rational;
 mod samplefmt;
@@ -19,6 +20,7 @@ pub use frame::*;
 pub use imgutils::*;
 pub use mem::*;
 pub use motion_vector::*;
+pub use pixdesc::*;
 pub use pixfmt::*;
 pub use rational::*;
 pub use samplefmt::*;
